#pragma once
#include <unordered_map>
#include <string>
#include "miniaudio.h"
#include <cstdint>

struct PlayingSound {
    uint64_t uaid;
    std::string name;
    ma_sound sound;
    double currentTime = 0.0;
    double totalTime = 0.0;

    void Stop() {
        ma_sound_stop(&sound);
        ma_sound_uninit(&sound);
    }
};

class AudioEngine {
public:
    static bool Init();
    static void Shutdown();

    static void Play(uint64_t uaid, bool loop = false);
    static void Stop(uint64_t uaid);
    static void StopAll();
    static void Unload(uint64_t uaid);
    static void Update();

    static ma_engine* GetEngine() { return &s_Engine; }
    static const std::unordered_map<uint64_t, PlayingSound>& GetPlayingSounds();

private:
    static ma_engine s_Engine;
    static std::unordered_map<uint64_t, PlayingSound> s_PlayingSounds;
};
